@@ -492,6 +492,10 @@ KArchiveDirectory *KArchive::findOrCreate(const QString &path)
         parent = findOrCreate(left);   // recursive call... until we find an existing dir.
     }
 
+    if (!parent) {
+        return nullptr;
+    }
+
     //qCDebug(KArchiveLog) << "found parent " << parent->name() << " adding " << dirname << " to ensure " << path;
     // Found -> add the missing piece
     KArchiveDirectory *e = new KArchiveDirectory(this, dirname, d->rootDir->permissions(),
@@ -939,7 +943,7 @@ bool KArchiveDirectory::copyTo(const QString &dest, bool recursiveCopy) const
         }
     } while (!dirStack.isEmpty());
 
-    qSort(fileList.begin(), fileList.end(), sortByPosition);    // sort on d->pos, so we have a linear access
+    std::sort(fileList.begin(), fileList.end(), sortByPosition);    // sort on d->pos, so we have a linear access
 
     for (QList<const KArchiveFile *>::const_iterator it = fileList.constBegin(), end = fileList.constEnd();
          it != end; ++it) {
